import { Switch, Route, useLocation } from "wouter";
import { queryClient } from "./lib/queryClient";
import { QueryClientProvider } from "@tanstack/react-query";
import { Toaster } from "@/components/ui/toaster";
import { TooltipProvider } from "@/components/ui/tooltip";
import { motion, AnimatePresence } from "framer-motion";
import { Suspense, lazy, useEffect } from "react";
import { preloadCriticalComponents } from "./lib/preloader";
import { Navbar } from "@/components/layout/Navbar";
import { Footer } from "@/components/layout/Footer";
import { BookPageWrapper, FloatingBookElements } from "@/components/transitions/PageTransition";
import { PageTurnSounds } from "@/components/transitions/PageTurnSounds";

// Import lightweight components directly
import NotFound from "@/pages/not-found";
import Home from "@/pages/home";
import Register from "@/pages/register";
import Login from "@/pages/login";
import Discovery from "@/pages/discovery"; // Load discovery immediately

// Lazy load other heavy components
const BookMap = lazy(() => import("@/pages/book-map"));
const Journey = lazy(() => import("@/pages/journey"));
const Bookshelf = lazy(() => import("@/pages/bookshelf"));
const GenreDiscovery = lazy(() => import("@/pages/genre-discovery"));
const BookDetails = lazy(() => import("@/pages/book-details"));

// Loading component for better UX
function PageLoader() {
  return (
    <div className="min-h-screen flex items-center justify-center">
      <motion.div
        className="flex flex-col items-center gap-4"
        initial={{ opacity: 0 }}
        animate={{ opacity: 1 }}
        transition={{ duration: 0.3 }}
      >
        <motion.div
          className="w-12 h-12 border-4 border-primary/20 border-t-primary rounded-full"
          animate={{ rotate: 360 }}
          transition={{ duration: 1, repeat: Infinity, ease: "linear" }}
        />
        <p className="text-sm text-gray-600">Loading page...</p>
      </motion.div>
    </div>
  );
}

function Router() {
  const [location] = useLocation();
  
  return (
    <div className="min-h-screen">
      {/* Paper background effect */}
      <div className="absolute inset-0 bg-gradient-to-br from-[#FFFAF5] via-[#FFF8F0] to-[#F5F0E8] opacity-30" />
      
      <div className="relative z-10">
        <Suspense fallback={<PageLoader />}>
          <Switch>
            <Route path="/" component={Home} />
            <Route path="/register" component={Register} />
            <Route path="/login" component={Login} />
            <Route path="/journey/:id" component={Journey} />
            <Route path="/book/:id" component={BookDetails} />
            <Route path="/paths" component={Journey} />
            <Route path="/book-map" component={BookMap} />
            <Route path="/discovery">
              {() => <Discovery key="discovery" />}
            </Route>
            <Route path="/bookshelf" component={Bookshelf} />
            <Route path="/books/surprise">
              {() => <Discovery key="surprise" />}
            </Route>
            <Route path="/genre-discovery" component={GenreDiscovery} />
            <Route component={NotFound} />
          </Switch>
        </Suspense>
      </div>
    </div>
  );
}

function App() {
  // Preload critical components on app start
  useEffect(() => {
    // Small delay to not block initial render
    const timer = setTimeout(() => {
      preloadCriticalComponents();
    }, 100);
    
    return () => clearTimeout(timer);
  }, []);

  return (
    <QueryClientProvider client={queryClient}>
      <TooltipProvider>
        <div className="min-h-screen flex flex-col paper-texture relative overflow-hidden">
          {/* Floating book elements for ambiance */}
          <FloatingBookElements />
          
          {/* Book spine on the left */}
          <motion.div
            className="fixed left-0 top-0 w-6 h-full bg-gradient-to-b from-amber-800 via-amber-700 to-amber-900 shadow-lg z-40"
            initial={{ x: -24 }}
            animate={{ x: 0 }}
            transition={{ duration: 0.8, delay: 0.2 }}
          >
            {/* Spine details */}
            <div className="absolute inset-y-0 left-1 w-0.5 bg-gradient-to-b from-amber-600 to-amber-800" />
            <div className="absolute inset-y-0 right-1 w-0.5 bg-gradient-to-b from-amber-900 to-amber-950" />
            <div className="absolute top-1/2 left-1/2 transform -translate-x-1/2 -translate-y-1/2 text-amber-100 text-xs font-bold tracking-wider transform -rotate-90 whitespace-nowrap">
              WEND
            </div>
          </motion.div>
          
          {/* Main content with margin for spine */}
          <div className="ml-6 relative z-10">
            <Navbar />
            <main className="flex-grow">
              <Router />
            </main>
            <Footer />
          </div>
          
          {/* Page turn sound effects - disabled */}
          {/* <PageTurnSounds /> */}
        </div>
        <Toaster />
      </TooltipProvider>
    </QueryClientProvider>
  );
}

export default App;
